@@ -2,7 +2,7 @@
 ** EncFile.cpp                                                          **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2019 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -86,7 +86,7 @@ void EncFile::read (istream &is) {
 			if (entry == ".notdef")
 				entry.clear();
 			if (n < 256)
-				_table[n++] = entry;
+				_table[n++] = std::move(entry);
 		}
 	}
 	// remove trailing .notdef names
