@@ -2,7 +2,7 @@
 ** GlyphTracerMessages.hpp                                              **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -45,7 +45,7 @@ class GlyphTracerMessages : public GFGlyphTracer::Callback {
 					if ((pos = fontname.rfind('/')) != std::string::npos)
 						fontname = fontname.substr(pos+1);
 					if ((pos = fontname.rfind('.')) != std::string::npos)
-						fontname = fontname.substr(0, pos);
+						fontname.resize(pos);
 					Message::mstream(false, Message::MC_STATE)
 						<< "tracing glyphs of " << fontname << '\n';
 				}
