@@ -2,7 +2,7 @@
 ** PDFHandler.hpp                                                       **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -18,8 +18,8 @@
 ** along with this program; if not, see <http://www.gnu.org/licenses/>. **
 *************************************************************************/
 
-#ifndef PDFHANDLER_HPP
-#define PDFHANDLER_HPP
+#ifndef PDFPAGE_HPP
+#define PDFPAGE_HPP
 
 #include <map>
 #include <string>
@@ -57,8 +57,8 @@ class PDFHandler {
 		const BoundingBox& bbox () const {return _bbox;}
 		std::unique_ptr<SVGElement> convert (const std::string &fname, int pageno, std::unique_ptr<SVGElement> context=nullptr);
 		static std::string mutoolVersion ();
-		static BoundingBox bbox (std::string &fname, int pageno);
 		static bool available () {return !mutoolVersion().empty();}
+		static int numberOfPages (const std::string &fname);
 
 	protected:
 		static std::string mutool (const std::string &cmd, bool readFromStderr=false);
@@ -77,6 +77,7 @@ class PDFHandler {
 		void collectObjects ();
 		void elementOpened (XMLElement *trcElement);
 		void elementClosed (XMLElement *trcElement);
+		void doPage (XMLElement *trcPageElement);
 		void doClipPath (XMLElement *trcClipPathElement);
 		void doClipStrokePath (XMLElement *trcClipStrokePathElement);
 		void doClipText (XMLElement *trcClipTextElement);
