@@ -2,7 +2,7 @@
 ** PdfSpecialHandler.cpp                                                **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -247,7 +247,7 @@ void PdfSpecialHandler::processBeginAnn (StreamInputReader &ir, SpecialActions &
 	it = annotDict.find("C");
 	if (it != annotDict.end())
 		HyperlinkManager::setDefaultLinkColor(to_color(it->second));
-	HyperlinkManager::instance().createLink(uri, actions);
+	HyperlinkManager::instance().createLink(std::move(uri), actions);
 }
 
 
@@ -283,7 +283,7 @@ void PdfSpecialHandler::dviEndPage (unsigned pageno, SpecialActions &actions) {
 }
 
 
-vector<const char*> PdfSpecialHandler::prefixes() const {
+vector<const char*> PdfSpecialHandler::prefixes () const {
 	vector<const char*> pfx {"pdf:"};
 	return pfx;
 }
