@@ -2,7 +2,7 @@
 ** SVGCharHandler.hpp                                                   **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -68,12 +68,14 @@ class SVGCharHandler {
 		virtual void appendChar (uint32_t c, double x, double y) =0;
 		virtual void notifyXAdjusted () {}
 		virtual void notifyYAdjusted () {}
-		void setColor (const Color &color)       {_color.set(color);}
+		void setFillColor (const Color &color)   {_fillColor.set(color);}
+		void setStrokeColor (const Color &color) {_strokeColor.set(color);}
 		void setOpacity (const Opacity &opacity) {_opacity.set(opacity);}
 		void setFont (const Font &font, int id)  {_font.set(&font); _fontnum = id;}
 		void setMatrix (const Matrix &matrix)    {_matrix.set(matrix);}
 		void setVertical (bool vertical)         {_vertical.set(vertical);}
-		Color getColor () const                  {return _color.get();}
+		Color getFillColor () const              {return _fillColor.get();}
+		Color getStrokeColor () const            {return _strokeColor.get();}
 		const Opacity& getOpacity () const       {return _opacity.get();}
 		const Font* getFont () const             {return _font.get();}
 		int getFontID () const                   {return _fontnum;}
@@ -88,7 +90,8 @@ class SVGCharHandler {
 			return _contextNodeStack.empty() ? _initialContextNode : _contextNodeStack.top();
 		}
 
-		CharProperty<Color> _color=Color::BLACK;   ///< current color
+		CharProperty<Color> _fillColor=Color::BLACK;    ///< current fill color
+		CharProperty<Color> _strokeColor=Color::BLACK;  ///< current stroke color
 		CharProperty<Opacity> _opacity;            ///< current opacity values
 		CharProperty<const Font*> _font=0;         ///< current font
 		int _fontnum=0;                            ///< current font ID
