@@ -2,7 +2,7 @@
 ** SVGOutput.hpp                                                        **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2019 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -33,9 +33,9 @@ struct SVGOutputBase {
 			HashTriple () =default;
 			HashTriple (std::string dviHash, std::string optHash, std::string cmbHash)
 				: _dviHash(std::move(dviHash)), _optHash(std::move(optHash)), _cmbHash(std::move(cmbHash)) {}
-			std::string dviHash () const {return _dviHash;}
-			std::string optHash () const {return _optHash;}
-			std::string cmbHash () const {return _cmbHash;}
+			const std::string& dviHash () const {return _dviHash;}
+			const std::string& optHash () const {return _optHash;}
+			const std::string& cmbHash () const {return _cmbHash;}
 			bool empty () const {return _dviHash.empty();}
 
 		private:
@@ -47,19 +47,22 @@ struct SVGOutputBase {
 	virtual ~SVGOutputBase () =default;
 	virtual std::ostream& getPageStream (int page, int numPages, const HashTriple &hashes=HashTriple()) const =0;
 	virtual FilePath filepath (int page, int numPages, const HashTriple &hashes= HashTriple()) const =0;
+	virtual void finish () =0;
 	virtual bool ignoresHashes () const {return true;}
 };
 
 
 class SVGOutput : public SVGOutputBase {
 	public:
-		SVGOutput () : SVGOutput("", "", 0) {}
+		SVGOutput () =default;
 		explicit SVGOutput (const std::string &base) : SVGOutput(base, "", 0) {}
 		SVGOutput (const std::string &base, const std::string &pattern) : SVGOutput(base, pattern, 0) {}
 		SVGOutput (const std::string &base, std::string pattern, int zipLevel);
 		std::ostream& getPageStream (int page, int numPages, const HashTriple &hash=HashTriple()) const override;
 		FilePath filepath (int page, int numPages, const HashTriple &hash=HashTriple()) const override;
+		void finish () override {_osptr.reset();}
 		bool ignoresHashes () const override;
+		void setFileNumbers (int fileNumber, int fileCount) {_fileNumber = fileNumber; _fileCount = fileCount;}
 
 	protected:
 		std::string expandFormatString (std::string str, int page, int numPages, const HashTriple &hashes) const;
@@ -67,9 +70,11 @@ class SVGOutput : public SVGOutputBase {
 	private:
 		FilePath _path;
 		std::string _pattern;
-		bool _stdout;      ///< write to STDOUT?
-		int _zipLevel;     ///< compression level
-		mutable int _page; ///< number of current page being written
+		bool _stdout=true;    ///< write to STDOUT?
+		int _zipLevel=0;      ///< compression level
+		int _fileNumber=1;    ///< current number of file in sequence of files
+		int _fileCount=1;     ///< number of files in sequence
+		mutable int _page=-1; ///< number of current page being written
 		mutable std::unique_ptr<std::ostream> _osptr;
 };
 
