@@ -2,7 +2,7 @@
 ** SVGTree.cpp                                                          **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -43,6 +43,7 @@ bool SVGTree::CREATE_USE_ELEMENTS=false;
 bool SVGTree::RELATIVE_PATH_CMDS=false;
 bool SVGTree::MERGE_CHARS=true;
 bool SVGTree::ADD_COMMENTS=false;
+bool SVGTree::EMBED_BITMAP_DATA = false;
 double SVGTree::ZOOM_FACTOR=1.0;
 
 
@@ -76,18 +77,25 @@ void SVGTree::setBBox (const BoundingBox &bbox) {
 }
 
 
-void SVGTree::setColor (const Color &c) {
+void SVGTree::setFillColor (const Color &c) {
 	const Font *font = _charHandler->getFont();
 	if (!font || font->color() == Color::BLACK)
-		_charHandler->setColor(c);
+		_charHandler->setFillColor(c);
+}
+
+
+void SVGTree::setStrokeColor (const Color &c) {
+	const Font *font = _charHandler->getFont();
+	if (!font || font->color() == Color::BLACK)
+		_charHandler->setStrokeColor(c);
 }
 
 
 void SVGTree::setFont (int num, const Font &font) {
 	_charHandler->setFont(font, num);
 	// set default color assigned to the font
-	if (font.color() != Color::BLACK && getColor() != font.color())
-		setColor(font.color());
+	if (font.color() != Color::BLACK && getFillColor() != font.color())
+		setFillColor(font.color());
 }
 
 
@@ -103,9 +111,9 @@ bool SVGTree::setFontFormat (string formatstr) {
 	string opt;
 	if (pos != string::npos) {
 		opt = formatstr.substr(pos+1);
-		formatstr = formatstr.substr(0, pos);
+		formatstr.resize(pos);
 	}
-	FontWriter::FontFormat format = FontWriter::toFontFormat(formatstr);
+	FontWriter::FontFormat format = FontWriter::toFontFormat(std::move(formatstr));
 	if (format == FontWriter::FontFormat::UNKNOWN)
 		return false;
 	FONT_FORMAT = format;
