@@ -2,7 +2,7 @@
 ** SpecialActions.hpp                                                   **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -27,12 +27,17 @@
 #include "Color.hpp"
 #include "FilePath.hpp"
 #include "Matrix.hpp"
+#include "MessageException.hpp"
 #include "Opacity.hpp"
 #include "SVGTree.hpp"
 
 class XMLElement;
 class XMLNode;
 
+struct SpecialException : public MessageException {
+	explicit SpecialException (const std::string &msg) : MessageException(msg) {}
+};
+
 class SpecialActions {
 	public:
 		virtual ~SpecialActions () =default;
@@ -41,8 +46,10 @@ class SpecialActions {
 		virtual void setX (double x) =0;
 		virtual void setY (double y) =0;
 		virtual void finishLine () =0;
-		virtual void setColor (const Color &color) =0;
-		virtual Color getColor () const =0;
+		virtual void setFillColor (const Color &color) =0;
+		virtual void setStrokeColor (const Color &color) =0;
+		virtual Color getFillColor () const =0;
+		virtual Color getStrokeColor () const =0;
 		virtual void setMatrix (const Matrix &m) =0;
 		virtual const Matrix& getMatrix () const =0;
 		virtual Matrix getPageTransformation () const {return Matrix(1);}
@@ -63,6 +70,7 @@ class SpecialActions {
 		virtual void lockOutput () {}
 		virtual void unlockOutput () {}
 		virtual bool outputLocked () const {return false;}
+		std::string expandText (const std::string &text);
 
 		static double PROGRESSBAR_DELAY; ///< progress bar doesn't appear before this time has elapsed (in sec)
 };
@@ -76,11 +84,13 @@ class EmptySpecialActions : public SpecialActions {
 		void setX (double x) override {}
 		void setY (double y) override {}
 		void finishLine ()  override {}
-		void setColor (const Color &color) override {}
+		void setFillColor (const Color &color) override {}
+		void setStrokeColor (const Color &color) override {}
 		void setBgColor (const Color &color) override {}
 		void setOpacity (const Opacity &opacity) override {}
 		const Opacity& getOpacity () const override {return _svg.getOpacity();}
-		Color getColor () const override {return Color::BLACK;}
+		Color getFillColor () const override {return Color::BLACK;}
+		Color getStrokeColor () const override {return Color::BLACK;}
 		void setMatrix (const Matrix &m) override {}
 		const Matrix& getMatrix () const override {return _matrix;}
 		const SVGTree& svgTree () const override {return _svg;}
