@@ -2,7 +2,7 @@
 ** utility.cpp                                                          **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -282,11 +282,11 @@ string util::mimetype (const string &fname) {
 	string ret;
 	auto pos = fname.rfind('.');
 	if (pos != string::npos) {
-		string suffix = fname.substr(pos+1);
+		string suffix = tolower(fname.substr(pos+1));
 		if (suffix == "svg")
 			ret = "svg+xml";
 		else if (suffix == "png" || suffix == "gif")
-			ret = suffix;
+			ret = std::move(suffix);
 		else if (suffix == "jpg" || suffix == "jpeg")
 			ret = "jpeg";
 		else if (suffix == "tif" || suffix == "tiff")
