@@ -28,10 +28,11 @@ using namespace std;
 class ColorSpecialTest : public ::testing::Test {
 	protected:
 		struct SetColor : EmptySpecialActions {
-			SetColor () : color(0) {}
-			void setColor (const Color &c) {color = uint32_t(c);}
-			bool equals (uint32_t c) {return color == c;}
-			uint32_t color;
+			void setFillColor (const Color &c) override   {fillColor = uint32_t(c);}
+			void setStrokeColor (const Color &c) override {strokeColor = uint32_t(c);}
+			bool equals (uint32_t c) const                {return fillColor == c && strokeColor == c;}
+			bool equals (uint32_t fc, uint32_t sc) const  {return fillColor == fc && strokeColor == sc;}
+			uint32_t fillColor=0, strokeColor=0;
 		};
 		ColorSpecialHandler handler;
 		SetColor actions;
@@ -73,6 +74,17 @@ TEST_F(ColorSpecialTest, rgb) {
 	std::istringstream iss("rgb 1 0 1");
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0xff00ff));
+	EXPECT_EQ(handler.stackSize(), 1u);
+	iss.clear();
+	iss.str("fill rgb 1 0 0");
+	handler.process("", iss, actions);
+	EXPECT_TRUE(actions.equals(0xff0000, 0xff00ff));
+	EXPECT_EQ(handler.stackSize(), 1u);
+	iss.clear();
+	iss.str("stroke rgb 0 1 1");
+	handler.process("", iss, actions);
+	EXPECT_TRUE(actions.equals(0xff0000, 0x00ffff));
+	EXPECT_EQ(handler.stackSize(), 1u);
 }
 
 
@@ -80,6 +92,7 @@ TEST_F(ColorSpecialTest, hsb) {
 	std::istringstream iss("hsb 1 0.5 1");
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0xff8080));
+	EXPECT_EQ(handler.stackSize(), 1u);
 }
 
 
@@ -87,6 +100,7 @@ TEST_F(ColorSpecialTest, cmyk) {
 	std::istringstream iss("cmyk 0.1 0.2 0.4 0.6");
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0x1a336699));
+	EXPECT_EQ(handler.stackSize(), 1u);
 }
 
 
@@ -94,18 +108,22 @@ TEST_F(ColorSpecialTest, stack1) {
 	std::istringstream iss("push rgb 1 0 0");
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0xff0000));
+	EXPECT_EQ(handler.stackSize(), 1u);
 	iss.clear();
 	iss.str("push Blue");
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0x0000ff));
+	EXPECT_EQ(handler.stackSize(), 2u);
 	iss.clear();
 	iss.str("pop");
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0xff0000));
+	EXPECT_EQ(handler.stackSize(), 1u);
 	iss.clear();
 	iss.str("pop");
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0x000000));
+	EXPECT_EQ(handler.stackSize(), 0u);
 }
 
 
@@ -113,17 +131,62 @@ TEST_F(ColorSpecialTest, stack2) {
 	std::istringstream iss("push rgb 1 0 0");
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0xff0000));
+	EXPECT_EQ(handler.stackSize(), 1u);
 	iss.clear();
 	iss.str("push rgb 0 1 0");
 	handler.process("", iss, actions);
+	EXPECT_EQ(handler.stackSize(), 2u);
 	iss.clear();
 	iss.str("gray 0.2");  // clear color stack implicitly
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0x333333));
+	EXPECT_EQ(handler.stackSize(), 1u);
 	iss.clear();
 	iss.str("pop");
 	handler.process("", iss, actions);
 	EXPECT_TRUE(actions.equals(0x000000));
+	EXPECT_EQ(handler.stackSize(), 0u);
+}
+
+
+TEST_F(ColorSpecialTest, stack3) {
+	std::istringstream iss("push fill cmyk 0.1 0.2 0.4 0.6");
+	handler.process("", iss, actions);
+	EXPECT_TRUE(actions.equals(0x1a336699, 0));
+	EXPECT_EQ(handler.stackSize(), 1u);
+	iss.clear();
+	iss.str("push stroke Blue");
+	handler.process("", iss, actions);
+	EXPECT_TRUE(actions.equals(0x1a336699, 0x0000ff));
+	EXPECT_EQ(handler.stackSize(), 2u);
+	iss.clear();
+	iss.str("set fill Green");
+	handler.process("", iss, actions);
+	EXPECT_TRUE(actions.equals(0x00ff00, 0x0000ff));
+	EXPECT_EQ(handler.stackSize(), 2u);
+	iss.clear();
+	iss.str("set White");
+	handler.process("", iss, actions);
+	EXPECT_TRUE(actions.equals(0xffffff));
+	EXPECT_EQ(handler.stackSize(), 2u);
+}
+
+
+TEST_F(ColorSpecialTest, stack4) {
+	std::istringstream iss("set stroke Cyan");
+	handler.process("", iss, actions);
+	EXPECT_TRUE(actions.equals(0, 0x00ffff));
+	EXPECT_EQ(handler.stackSize(), 0u);
+	iss.clear();
+	iss.str("push fill Blue");
+	handler.process("", iss, actions);
+	EXPECT_TRUE(actions.equals(0x0000ff, 0x00ffff));
+	EXPECT_EQ(handler.stackSize(), 1u);
+	iss.clear();
+	iss.str("pop");
+	handler.process("", iss, actions);
+	EXPECT_TRUE(actions.equals(0, 0x00ffff));
+	EXPECT_EQ(handler.stackSize(), 0u);
 }
 
 
