@@ -2,7 +2,7 @@
 ** DvisvgmSpecialTest.cpp                                               **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -20,11 +20,16 @@
 
 #include <gtest/gtest.h>
 #include <array>
+#include <regex>
 #include <sstream>
 #include "DvisvgmSpecialHandler.hpp"
 #include "SpecialActions.hpp"
 #include "XMLNode.hpp"
 
+#ifndef SRCDIR
+#define SRCDIR "."
+#endif
+
 using namespace std;
 
 
@@ -47,15 +52,20 @@ class DvisvgmSpecialTest : public ::testing::Test {
 	protected:
 		class ActionsRecorder : public EmptySpecialActions {
 			public:
-				void embed (const BoundingBox &bb) override   {bbox.embed(bb);}
-				double getX () const override                 {return -42;}
-				double getY () const override                 {return 14;}
-				bool defsEquals (const string &str) const     {return defsString() == str;}
-				bool pageEquals (const string &str) const     {return pageString() == str;}
-				bool bboxEquals (const string &str) const     {return bbox.svgViewBoxString() == str;}
-				string bboxString () const                    {return bbox.svgViewBoxString();}
-				string defsString () const                    {return toString(svgTree().defsNode());}
-				string pageString () const                    {return toString(svgTree().pageNode());}
+				void embed (const BoundingBox &bb) override    {bbox.embed(bb);}
+				double getX () const override                  {return -42;}
+				double getY () const override                  {return 14;}
+				unsigned getCurrentPageNumber() const override {return 1;}
+				Color getFillColor () const override           {return Color(0xff0000);}
+				Color getStrokeColor () const override         {return Color(0x00ff00);}
+				FilePath getSVGFilePath(unsigned pageno) const override {return FilePath("test.svg");}
+				bool defsEquals (const string &str) const      {return defsString() == str;}
+				bool pageEquals (const string &str) const      {return pageString() == str;}
+				bool pageMatches (const string &pattern) const {return regex_match(pageString(), regex(pattern));}
+				bool bboxEquals (const string &str) const      {return bbox.svgViewBoxString() == str;}
+				string bboxString () const                     {return bbox.svgViewBoxString();}
+				string defsString () const                     {return toString(svgTree().defsNode());}
+				string pageString () const                     {return toString(svgTree().pageNode());}
 
 				void clear () {
 					SpecialActions::svgTree().reset();
@@ -317,16 +327,16 @@ TEST_F(DvisvgmSpecialTest, fail2) {
 
 
 TEST_F(DvisvgmSpecialTest, processImg) {
-	std::istringstream iss("img 72.27 72.27 test.png");
+	std::istringstream iss("img 72.27 72.27 " SRCDIR "/data/rectangle.png");
 	handler.process("", iss, recorder);
 	EXPECT_TRUE(recorder.defsEquals(""));
-	EXPECT_TRUE(recorder.pageEquals("<g id='page1'><image x='-42' y='14' width='72' height='72' xlink:href='test.png'/></g>")) << recorder.pageString();
+	EXPECT_TRUE(recorder.pageMatches("<g id='page1'><image x='-42' y='-58' width='72' height='72' xlink:href='.*rectangle.png'/></g>")) << recorder.pageString();
 
 	recorder.clear();
 	iss.clear();
-	iss.str("img 10bp 20bp test2.png");
+	iss.str("img 10bp 20bp " SRCDIR "/data/rectangle.png");
 	handler.process("", iss, recorder);
-	EXPECT_TRUE(recorder.pageEquals("<g id='page1'><image x='-42' y='14' width='10' height='20' xlink:href='test2.png'/></g>")) << recorder.pageString();
+	EXPECT_TRUE(recorder.pageMatches("<g id='page1'><image x='-42' y='-6' width='10' height='20' xlink:href='.*rectangle.png'/></g>")) << recorder.pageString();
 }
 
 
@@ -369,6 +379,18 @@ TEST_F(DvisvgmSpecialTest, processBBox) {
 }
 
 
+TEST_F(DvisvgmSpecialTest, expandText) {
+	EXPECT_EQ(recorder.expandText(""), "");
+	EXPECT_EQ(recorder.expandText("static text"), "static text");
+	EXPECT_EQ(recorder.expandText("x={?x}, y={?y}"), "x=-42, y=14");
+	EXPECT_EQ(recorder.expandText("page:{?pageno}, file:{?svgfile}"), "page:1, file:test.svg");
+	EXPECT_EQ(recorder.expandText("xxx{?cmyk(1,0,1,0)}yyy"), "xxx#00a650yyy");
+	EXPECT_EQ(recorder.expandText("xxx{?cmyk(1,0,1,0)}yyy{?cmyk(1,0,0,0)}zzz"), "xxx#00a650yyy#00aeefzzz");
+	EXPECT_EQ(recorder.expandText("fill='{?fillcolor}' stroke='{?strokecolor}'"), "fill='#f00' stroke='#0f0'");
+	EXPECT_EQ(recorder.expandText("stroke='{?color}'"), "stroke='#f00'");
+}
+
+
 TEST_F(DvisvgmSpecialTest, fail4) {
 	std::istringstream iss("bbox abs 0 0 72.27xx 72.27");  // unknown unit
 	EXPECT_THROW(handler.process("", iss, recorder), SpecialException);
