@@ -2,7 +2,7 @@
 ** StreamInputBufferTest.cpp                                            **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2024 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -43,6 +43,27 @@ TEST(StreamInputBufferTest, get) {
 }
 
 
+TEST(StreamInputBufferTest, read) {
+	istringstream iss("abcdefghijklmnopqrst");
+	StreamInputReader ir(iss);
+	char buf[10];
+	auto count = ir.read(buf, 9);
+	ASSERT_EQ(count, 9);
+	buf[count] = 0;
+	EXPECT_EQ(string(buf), "abcdefghi");
+
+	count = ir.read(buf, 9);
+	ASSERT_EQ(count, 9);
+	buf[count] = 0;
+	EXPECT_EQ(string(buf), "jklmnopqr");
+
+	count = ir.read(buf, 9);
+	ASSERT_EQ(count, 2);
+	buf[count] = 0;
+	EXPECT_EQ(string(buf), "st");
+}
+
+
 TEST(StreamInputBufferTest, peek) {
 	istringstream iss("abcdefghijklmnopqrstuvwxyz");
 	StreamInputBuffer buffer(iss, 10);
